Page 154 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 154

Home

    General of the conference, and who helped draft the UN
    Charter, was CFR member Alger Hiss. Later, Hiss was

    discovered to be a Soviet spy and served time in prison
    for lying about his connections to a Soviet spy ring. In
    addition to Hiss, more than forty other American
    delegates to the UN founding conference were members
    of the CFR.

    Alger Hiss took the UN Charter back to Washington
    in a small safe, and the Uz S. Senate ratified the

    document without studying its contents. After the U. S.
    became a part of world government, John D. Rockefeller
    donated $8.5 million to purchase land for the UN

    building.

    From the very beginning the UN was a big business
    proposition. Part of it was launched with the formation
    (by CFR members) of the International Monetary Fund
    (IMF) and the World Bank at the Bretton Woods
    Conference of 1944. Closely linked with Rockefeller's
    Chase Manhattan Bank, the World Bank has been used

    money.
    The beneficiaries of this money have not been the

    poor people in undeveloped countries, but wealthy
    industrialists who wish to expand operations in these
    countries. Congressman John Rarick explained it this
    way, "Aid to the poor countries usually ends up as seed
    money or loans to the wealthy industrialists from the
    developed countries to further their overseas operations
    in competition with the people whose country they claim

    149

    U.N. Modern Tower of Babel

    to lend money around the world, mostly U. S. taxpayers’